==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgs, _super);
    function DomainChartSeriesPointerEventArgs(a, b) {
        var _this = _super.call(this) || this;
        _this._series = null;
        _this._item = null;
        _this.series = a;
        _this.item = b;
        return _this;
    }
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "series", {
        get: function () {
            return this._series;
        },
        set: function (a) {
            this._series = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "item", {
        get: function () {
            return this._item;
        },
        set: function (a) {
            this._item = a;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartSeriesPointerEventArgs.$t = markType(DomainChartSeriesPointerEventArgs, 'DomainChartSeriesPointerEventArgs');
    return DomainChartSeriesPointerEventArgs;
}(Base));
export { DomainChartSeriesPointerEventArgs };

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgs, _super);
    function DomainChartSeriesPointerEventArgs(a, b, c) {
        var _this = _super.call(this) || this;
        _this.e = { $type: Point_$type, x: NaN, y: NaN };
        _this._series = null;
        _this._item = null;
        _this._plotAreaPosition = null;
        _this.b = false;
        _this.series = a;
        _this.item = b;
        _this.plotAreaPosition = c;
        return _this;
    }
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "series", {
        get: function () {
            return this._series;
        },
        set: function (a) {
            this._series = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "item", {
        get: function () {
            return this._item;
        },
        set: function (a) {
            this._item = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return this._plotAreaPosition;
        },
        set: function (a) {
            this._plotAreaPosition = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "chartPosition", {
        get: function () {
            if (isNaN_(this.e.x) && isNaN_(this.e.y)) {
                this.e.x = this.plotAreaPosition.x - this.series.c9.wj.left;
                this.e.y = this.plotAreaPosition.y - this.series.c9.wj.top;
            }
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "cancelSelection", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            this.b = a;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartSeriesPointerEventArgs.$t = markType(DomainChartSeriesPointerEventArgs, 'DomainChartSeriesPointerEventArgs');
    return DomainChartSeriesPointerEventArgs;
}(Base));
export { DomainChartSeriesPointerEventArgs };
